@@ -43,14 +43,18 @@
 #' run_mlm(mat, net, minsize=0)
 run_mlm <- function(mat,
                     network,
-                    .source = .data$source,
-                    .target = .data$target,
-                    .mor = .data$mor,
-                    .likelihood = .data$likelihood,
+                    .source = source,
+                    .target = target,
+                    .mor = mor,
+                    .likelihood = likelihood,
                     sparse = FALSE,
                     center = FALSE,
                     na.rm = FALSE,
                     minsize = 5) {
+
+    # NSE vs. R CMD check workaround
+    condition <- likelihood <- mor <- p_value <- score <- source <- statistic    <- target <- NULL
+
   # Check for NAs/Infs in mat
   mat <- check_nas_infs(mat)
   
@@ -92,8 +96,8 @@ run_mlm <- function(mat,
         # list of tables.
         #
         res_all = list(res_all)
-        names(res_all) <- colnames(mat)
     }
+    names(res_all) <- colnames(mat)
     
     # summary is a list for each condition. Get the info we need: 
     res_new <- res_all %>% lapply(X = ., function(fit){
@@ -109,10 +113,9 @@ run_mlm <- function(mat,
         }
         tibble(score=scores, p_value=pvals, source=sources)
     }) %>% bind_rows(.id = "condition") %>%
-        mutate(condition = gsub("Response ","", .data$condition)) %>%
         mutate(statistic = "mlm", .before= 1) %>%
-        select(.data$statistic, .data$source, .data$condition,
-               .data$score, .data$p_value)
+        select(statistic, source, condition,
+               score, p_value)
     return(res_new)
 }
 
