@@ -43,10 +43,10 @@ head(deg)
 net <- get_collectri(organism='human', split_complexes=FALSE)
 net
 
-## ----"sample_wmean", message=FALSE------------------------------------------------------------------------------------
-# Run wmean
-sample_acts <- run_wmean(mat=counts, net=net, .source='source', .target='target',
-                  .mor='mor', times = 100, minsize = 5)
+## ----"sample_ulm", message=FALSE--------------------------------------------------------------------------------------
+# Run ulm
+sample_acts <- run_ulm(mat=counts, net=net, .source='source', .target='target',
+                  .mor='mor', minsize = 5)
 sample_acts
 
 ## ----"heatmap"--------------------------------------------------------------------------------------------------------
@@ -54,7 +54,6 @@ n_tfs <- 25
 
 # Transform to wide matrix
 sample_acts_mat <- sample_acts %>%
-  filter(statistic == 'norm_wmean') %>%
   pivot_wider(id_cols = 'condition', names_from = 'source',
               values_from = 'score') %>%
   column_to_rownames('condition') %>%
@@ -82,19 +81,17 @@ my_breaks <- c(seq(-3, 0, length.out=ceiling(palette_length/2) + 1),
 # Plot
 pheatmap(sample_acts_mat, border_color = NA, color=my_color, breaks = my_breaks) 
 
-## ----"contrast_wmean", message=FALSE----------------------------------------------------------------------------------
-# Run wmean
-contrast_acts <- run_wmean(mat=deg[, 't', drop=FALSE], net=net, .source='source', .target='target',
-                  .mor='mor', times = 100, minsize = 5)
+## ----"contrast_ulm", message=FALSE------------------------------------------------------------------------------------
+# Run ulm
+contrast_acts <- run_ulm(mat=deg[, 't', drop=FALSE], net=net, .source='source', .target='target',
+                  .mor='mor', minsize = 5)
 contrast_acts
 
 ## ----"barplot"--------------------------------------------------------------------------------------------------------
-# Filter norm_wmean
-f_contrast_acts <- contrast_acts %>%
-  filter(statistic == 'norm_wmean') %>%
-  mutate(rnk = NA)
 
 # Filter top TFs in both signs
+f_contrast_acts <- contrast_acts %>%
+  mutate(rnk = NA)
 msk <- f_contrast_acts$score > 0
 f_contrast_acts[msk, 'rnk'] <- rank(-f_contrast_acts[msk, 'score'])
 f_contrast_acts[!msk, 'rnk'] <- rank(-abs(f_contrast_acts[!msk, 'score']))
@@ -117,10 +114,10 @@ ggplot(f_contrast_acts, aes(x = reorder(source, score), y = score)) +
         axis.text.y = element_text(size =10, face= "bold"),
         panel.grid.major = element_blank(), 
         panel.grid.minor = element_blank()) +
-    xlab("Pathways")
+    xlab("TFs")
 
 ## ----"targets", warning=F---------------------------------------------------------------------------------------------
-tf <- 'FOXA2'
+tf <- 'SP1'
 
 df <- net %>%
   filter(source == tf) %>%
